==> ejc-procurement-impl-3.0.0-20251203.095500-23-sources.jar: com/ejianc/business/procurement/plan/controller/PurchaseStrategyChangeController.java <==
package com.ejianc.business.procurement.plan.controller;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.LambdaUpdateWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.business.procurement.plan.bean.PurchaseStrategyChangeEntity;
import com.ejianc.business.procurement.plan.bean.PurchaseStrategyEntity;
import com.ejianc.business.procurement.plan.bean.PurchaseStrategyRecordEntity;
import com.ejianc.business.procurement.plan.service.IPurchaseStrategyChangeService;
import com.ejianc.business.procurement.plan.service.IPurchaseStrategyRecordService;
import com.ejianc.business.procurement.plan.service.IPurchaseStrategyService;
import com.ejianc.business.procurement.plan.vo.PurchaseStrategyChangeVO;
import com.ejianc.business.procurement.plan.vo.PurchaseStrategyRecordVO;
import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.foundation.support.api.IBillCodeApi;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.foundation.support.vo.BillCodeParam;
import com.ejianc.framework.auth.session.SessionManager;
import com.ejianc.framework.auth.session.UserContext;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.kit.collection.ListUtil;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.response.BillStateEnum;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;
import com.ejianc.framework.core.util.ExcelExport;
import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.io.Serializable;
import java.util.*;
import java.util.stream.Collectors;

/**
 * 采购策划变更
 *
 * @author generator
 *
 */
@Controller
@RequestMapping("purchaseStrategyChange")
public class PurchaseStrategyChangeController implements Serializable {
    private static final long serialVersionUID = 1L;

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IBillTypeApi billTypeApi;
    @Autowired
    private IBillCodeApi billCodeApi;
    @Autowired
    private IOrgApi iOrgApi;

    private static final String BILL_CODE = "PURCHASE_STRATEGY_CHANGE_CODE";

    @Autowired
    private IPurchaseStrategyChangeService service;

    @Autowired
    private SessionManager sessionManager;

    @Autowired
    private IPurchaseStrategyService strategyService;

    @Autowired
    private IPurchaseStrategyRecordService recordService;

    /**
     * @Description saveOrUpdate 新增或者修改
     */
    @RequestMapping(value = "/saveOrUpdate", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<PurchaseStrategyChangeVO> saveOrUpdate(@RequestBody PurchaseStrategyChangeVO saveOrUpdateVO) {
        PurchaseStrategyChangeEntity entity = BeanMapper.map(saveOrUpdateVO, PurchaseStrategyChangeEntity.class);
        if (entity.getId() == null || entity.getId() == 0) {
            BillCodeParam billCodeParam = BillCodeParam.build(BILL_CODE, InvocationInfoProxy.getTenantid(), saveOrUpdateVO);
            CommonResponse<String> billCode = billCodeApi.generateBillCode(billCodeParam);
            if (billCode.isSuccess()) {
                entity.setBillCode(billCode.getData());
            } else {
                throw new BusinessException("网络异常， 编码生成失败， 请稍后再试");
            }
        }
        PurchaseStrategyEntity masterPlan = strategyService.getById(entity.getSourcePlanId());
        if (null == entity.getId()) {
            //变更版本号
            entity.setChangeVersion(masterPlan.getChangeVersion() + 1);
            entity.setCurChangingPlanCode(masterPlan.getBillCode());
        }
        boolean b = service.saveOrUpdate(entity, false);
        if (b) {
            LambdaUpdateWrapper<PurchaseStrategyEntity> wrapper = new LambdaUpdateWrapper<>();
            wrapper.eq(PurchaseStrategyEntity::getId, entity.getSourcePlanId());
            wrapper.set(PurchaseStrategyEntity::getCurChangingPlanId, entity.getId());
            wrapper.set(PurchaseStrategyEntity::getCurChangingPlanCode, entity.getBillCode());
            wrapper.set(PurchaseStrategyEntity::getChangeState, 1);
            strategyService.update(wrapper);
        }
        PurchaseStrategyChangeVO vo = BeanMapper.map(entity, PurchaseStrategyChangeVO.class);
        return CommonResponse.success("保存或修改单据成功！", vo);
    }

    /**
     * @Description queryDetail 查询详情
     * @param id
     */
    @RequestMapping(value = "/queryDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<PurchaseStrategyChangeVO> queryDetail(Long id) {
        PurchaseStrategyChangeEntity entity = service.selectById(id);
        PurchaseStrategyChangeVO vo = BeanMapper.map(entity, PurchaseStrategyChangeVO.class);
        return CommonResponse.success("查询详情数据成功！", vo);
    }

    /**
     * @Description delete 批量删除单据
     * @Param [ids]
     */
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> delete(@RequestBody List<PurchaseStrategyChangeVO> vos) {
        if (ListUtil.isNotEmpty(vos)) {
            PurchaseStrategyChangeVO changeVo = vos.get(0);
            PurchaseStrategyChangeEntity changeEntity = service.getById(changeVo.getId());
            Long sourcePlanId = changeEntity.getSourcePlanId();
            LambdaQueryWrapper<PurchaseStrategyChangeEntity> changeQueryWrapper = new LambdaQueryWrapper<>();
            changeQueryWrapper.eq(PurchaseStrategyChangeEntity::getSourcePlanId, sourcePlanId);
            changeQueryWrapper.ne(PurchaseStrategyChangeEntity::getId, changeEntity.getId());
            changeQueryWrapper.notIn(PurchaseStrategyChangeEntity::getBillState, Arrays.asList(BillStateEnum.COMMITED_STATE.getBillStateCode(), BillStateEnum.PASSED_STATE.getBillStateCode()));
            changeQueryWrapper.orderByDesc(PurchaseStrategyChangeEntity::getCreateTime);
            List<PurchaseStrategyChangeEntity> list = service.list(changeQueryWrapper);
            LambdaUpdateWrapper<PurchaseStrategyEntity> wrapper = new LambdaUpdateWrapper<>();
            wrapper.eq(PurchaseStrategyEntity::getId, sourcePlanId);
            if (CollectionUtils.isNotEmpty(list)) {
                wrapper.set(PurchaseStrategyEntity::getCurChangingPlanId, list.get(0).getId());
                wrapper.set(PurchaseStrategyEntity::getCurChangingPlanCode, list.get(0).getBillCode());
                wrapper.set(PurchaseStrategyEntity::getChangeState, 1);
            } else {
                LambdaQueryWrapper<PurchaseStrategyRecordEntity> recordEntityLambdaUpdateWrapper = new LambdaQueryWrapper<>();
                recordEntityLambdaUpdateWrapper.eq(PurchaseStrategyRecordEntity::getSourcePlanId, sourcePlanId);
                int count = recordService.count(recordEntityLambdaUpdateWrapper);
                wrapper.set(PurchaseStrategyEntity::getCurChangingPlanId, null);
                wrapper.set(PurchaseStrategyEntity::getCurChangingPlanCode, null);
                wrapper.set(PurchaseStrategyEntity::getChangeState, count == 0 ? 0 : 2);
            }
            strategyService.update(wrapper);
            service.removeByIds(vos.stream().map(PurchaseStrategyChangeVO::getId).collect(Collectors.toList()), false);
        }
        return CommonResponse.success("删除成功！");
    }

    /**
     * @Description queryList 查询列表
     * @param param
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<PurchaseStrategyChangeVO>> queryList(@RequestBody QueryParam param) {

        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));

        /** 数据隔离 本下 没有组织orgId的删除下面代码-------------开始 */
        UserContext userContextCache = sessionManager.getUserContext();
        //当前应用有权限的根orgId，以逗号分割，可据此查询其本下数据，需判空
        String authOrgIds = userContextCache.getAuthOrgIds();
        List<OrgVO> orgVOList = null;
        if (StringUtils.isNotBlank(authOrgIds)) {//移动端查询
            orgVOList = (List<OrgVO>) getRespData(iOrgApi.findChildrenByParentIds(Arrays.stream(authOrgIds.split(",")).map(Long::parseLong).collect(Collectors.toList())), true, "查询失败，获取当前本下组织信息失败。");
        } else {//pc端查询
            orgVOList = (List<OrgVO>) getRespData(iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()), true, "查询失败，获取当前本下组织信息失败。");
        }
        //普通组织 id
        List<Long> commonOrgIds = new ArrayList<>();
        //项目部 id
        List<Long> departmentIds = new ArrayList<>();
        orgVOList.stream().forEach(org -> {
            if (5 == org.getOrgType()) {
                //项目部
                departmentIds.add(org.getId());
            } else {
                //普通组织
                commonOrgIds.add(org.getId());
            }
        });
        if (CollectionUtils.isNotEmpty(commonOrgIds)) {
            /** 要求主表有orgId字段，保存单据所属组织 */
            param.getParams().put("orgId", new Parameter(QueryParam.IN, commonOrgIds));
        } else if (CollectionUtils.isNotEmpty(departmentIds)) {
            /** 要求主表有projectDepartmentId字段，保存单据所属项目部 */
            param.getParams().put("orgId", new Parameter(QueryParam.IN, departmentIds));
        }
        /** 数据隔离 本下 没有组织orgId的删除上面代码-------------结束！！！ */

        IPage<PurchaseStrategyChangeEntity> page = service.queryPage(param, false);
        IPage<PurchaseStrategyChangeVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), PurchaseStrategyChangeVO.class));

        return CommonResponse.success("查询列表数据成功！", pageData);
    }

    /**
     * 获取RPC数据
     * resp 返回值
     * isMustSuc 是否必须成功
     * errMsg 失败提示
     */
    private Object getRespData(CommonResponse<?> resp, boolean isMustSuc, String errMsg) {
        if (isMustSuc && !resp.isSuccess()) {
            throw new BusinessException(StringUtils.isNoneBlank(errMsg) ? errMsg : "调用Rpc服务失败");
        }
        return resp.getData();
    }


    /**
     * @Description 导出
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/excelExport", method = RequestMethod.POST)
    @ResponseBody
    public void excelExport(@RequestBody QueryParam param, HttpServletResponse response) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        param.getParams().put("tenant_id", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        param.setPageIndex(1);
        param.setPageSize(-1);
        /** 数据隔离 本下 没有组织orgId的删除下面代码 */
        param.getParams().put("orgId", new Parameter(QueryParam.IN, iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        List<PurchaseStrategyChangeEntity> list = service.queryList(param);
        //todo:字段翻译等等
        Map<String, Object> beans = new HashMap<>();
        beans.put("records", list);
        ExcelExport.getInstance().export("PurchaseStrategyChange-export.xlsx", beans, response);
    }

    /**
     * @Description 参照
     * @Return void
     */
    @RequestMapping(value = "/refPurchaseStrategyChangeData", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<IPage<PurchaseStrategyChangeVO>> refPurchaseStrategyChangeData(@RequestParam Integer pageNumber, @RequestParam Integer pageSize,
                                                                                         String condition,
                                                                                         String searchObject,
                                                                                         String searchText) {
        QueryParam param = new QueryParam();
        param.setPageSize(pageSize);
        param.setPageIndex(pageNumber);
        param.setSearchText(searchText);
        param.setSearchObject(searchObject);
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        if (StringUtils.isNotEmpty(condition)) {
            /** 处理condition */
            JSONObject _con = JSONObject.parseObject(condition);
        }

        IPage<PurchaseStrategyChangeEntity> page = service.queryPage(param, false);
        IPage<PurchaseStrategyChangeVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), PurchaseStrategyChangeVO.class));

        return CommonResponse.success("查询参照数据成功！", pageData);
    }
}

==> ejc-procurement-impl-3.0.0-20251204.031535-35-sources.jar: com/ejianc/business/procurement/plan/controller/PurchaseStrategyChangeController.java <==
package com.ejianc.business.procurement.plan.controller;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.LambdaUpdateWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.business.procurement.plan.bean.PurchaseStrategyChangeEntity;
import com.ejianc.business.procurement.plan.bean.PurchaseStrategyEntity;
import com.ejianc.business.procurement.plan.bean.PurchaseStrategyRecordEntity;
import com.ejianc.business.procurement.plan.service.IPurchaseStrategyChangeService;
import com.ejianc.business.procurement.plan.service.IPurchaseStrategyRecordService;
import com.ejianc.business.procurement.plan.service.IPurchaseStrategyService;
import com.ejianc.business.procurement.plan.vo.PurchaseStrategyChangeVO;
import com.ejianc.business.procurement.plan.vo.PurchaseStrategyRecordVO;
import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.foundation.support.api.IBillCodeApi;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.foundation.support.vo.BillCodeParam;
import com.ejianc.framework.auth.session.SessionManager;
import com.ejianc.framework.auth.session.UserContext;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.kit.collection.ListUtil;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.response.BillStateEnum;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;
import com.ejianc.framework.core.util.ExcelExport;
import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.io.Serializable;
import java.util.*;
import java.util.stream.Collectors;

/**
 * 采购策划变更
 *
 * @author generator
 *
 */
@Controller
@RequestMapping("purchaseStrategyChange")
public class PurchaseStrategyChangeController implements Serializable {
    private static final long serialVersionUID = 1L;

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IBillTypeApi billTypeApi;
    @Autowired
    private IBillCodeApi billCodeApi;
    @Autowired
    private IOrgApi iOrgApi;

    private static final String BILL_CODE = "PURCHASE_STRATEGY_CHANGE_CODE";

    @Autowired
    private IPurchaseStrategyChangeService service;

    @Autowired
    private SessionManager sessionManager;

    @Autowired
    private IPurchaseStrategyService strategyService;

    @Autowired
    private IPurchaseStrategyRecordService recordService;

    private static Map<String, String> codeRuleMap = new HashMap<>();

    static {
        codeRuleMap.put("2", "PURCHASE_STRATEGY_CHANGE_CODE");
        codeRuleMap.put("1", "PURCHASE_STRATEGY_CHANGE_GC_CODE");
        codeRuleMap.put("3", "PURCHASE_STRATEGY_CHANGE_FW_CODE");
    }


    /**
     * @Description saveOrUpdate 新增或者修改
     */
    @RequestMapping(value = "/saveOrUpdate", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<PurchaseStrategyChangeVO> saveOrUpdate(@RequestBody PurchaseStrategyChangeVO saveOrUpdateVO) {
        PurchaseStrategyChangeEntity entity = BeanMapper.map(saveOrUpdateVO, PurchaseStrategyChangeEntity.class);
        if (entity.getId() == null || entity.getId() == 0) {
            BillCodeParam billCodeParam = BillCodeParam.build(codeRuleMap.get(entity.getBusinessType()), InvocationInfoProxy.getTenantid(), saveOrUpdateVO);
            CommonResponse<String> billCode = billCodeApi.generateBillCode(billCodeParam);
            if (billCode.isSuccess()) {
                entity.setBillCode(billCode.getData());
            } else {
                throw new BusinessException("网络异常， 编码生成失败， 请稍后再试");
            }
        }
        PurchaseStrategyEntity masterPlan = strategyService.getById(entity.getSourcePlanId());
        if (null == entity.getId()) {
            //变更版本号
            entity.setChangeVersion(masterPlan.getChangeVersion() + 1);
            entity.setCurChangingPlanCode(masterPlan.getBillCode());
        }
        boolean b = service.saveOrUpdate(entity, false);
        if (b) {
            LambdaUpdateWrapper<PurchaseStrategyEntity> wrapper = new LambdaUpdateWrapper<>();
            wrapper.eq(PurchaseStrategyEntity::getId, entity.getSourcePlanId());
            wrapper.set(PurchaseStrategyEntity::getCurChangingPlanId, entity.getId());
            wrapper.set(PurchaseStrategyEntity::getCurChangingPlanCode, entity.getBillCode());
            wrapper.set(PurchaseStrategyEntity::getChangeState, 1);
            strategyService.update(wrapper);
        }
        PurchaseStrategyChangeVO vo = BeanMapper.map(entity, PurchaseStrategyChangeVO.class);
        return CommonResponse.success("保存或修改单据成功！", vo);
    }

    /**
     * @Description queryDetail 查询详情
     * @param id
     */
    @RequestMapping(value = "/queryDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<PurchaseStrategyChangeVO> queryDetail(Long id) {
        PurchaseStrategyChangeEntity entity = service.selectById(id);
        PurchaseStrategyChangeVO vo = BeanMapper.map(entity, PurchaseStrategyChangeVO.class);
        return CommonResponse.success("查询详情数据成功！", vo);
    }

    /**
     * @Description delete 批量删除单据
     * @Param [ids]
     */
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> delete(@RequestBody List<PurchaseStrategyChangeVO> vos) {
        if (ListUtil.isNotEmpty(vos)) {
            PurchaseStrategyChangeVO changeVo = vos.get(0);
            PurchaseStrategyChangeEntity changeEntity = service.getById(changeVo.getId());
            Long sourcePlanId = changeEntity.getSourcePlanId();
            LambdaQueryWrapper<PurchaseStrategyChangeEntity> changeQueryWrapper = new LambdaQueryWrapper<>();
            changeQueryWrapper.eq(PurchaseStrategyChangeEntity::getSourcePlanId, sourcePlanId);
            changeQueryWrapper.ne(PurchaseStrategyChangeEntity::getId, changeEntity.getId());
            changeQueryWrapper.notIn(PurchaseStrategyChangeEntity::getBillState, Arrays.asList(BillStateEnum.COMMITED_STATE.getBillStateCode(), BillStateEnum.PASSED_STATE.getBillStateCode()));
            changeQueryWrapper.orderByDesc(PurchaseStrategyChangeEntity::getCreateTime);
            List<PurchaseStrategyChangeEntity> list = service.list(changeQueryWrapper);
            LambdaUpdateWrapper<PurchaseStrategyEntity> wrapper = new LambdaUpdateWrapper<>();
            wrapper.eq(PurchaseStrategyEntity::getId, sourcePlanId);
            if (CollectionUtils.isNotEmpty(list)) {
                wrapper.set(PurchaseStrategyEntity::getCurChangingPlanId, list.get(0).getId());
                wrapper.set(PurchaseStrategyEntity::getCurChangingPlanCode, list.get(0).getBillCode());
                wrapper.set(PurchaseStrategyEntity::getChangeState, 1);
            } else {
                LambdaQueryWrapper<PurchaseStrategyRecordEntity> recordEntityLambdaUpdateWrapper = new LambdaQueryWrapper<>();
                recordEntityLambdaUpdateWrapper.eq(PurchaseStrategyRecordEntity::getSourcePlanId, sourcePlanId);
                int count = recordService.count(recordEntityLambdaUpdateWrapper);
                wrapper.set(PurchaseStrategyEntity::getCurChangingPlanId, null);
                wrapper.set(PurchaseStrategyEntity::getCurChangingPlanCode, null);
                wrapper.set(PurchaseStrategyEntity::getChangeState, count == 0 ? 0 : 2);
            }
            strategyService.update(wrapper);
            service.removeByIds(vos.stream().map(PurchaseStrategyChangeVO::getId).collect(Collectors.toList()), false);
        }
        return CommonResponse.success("删除成功！");
    }

    /**
     * @Description queryList 查询列表
     * @param param
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<PurchaseStrategyChangeVO>> queryList(@RequestBody QueryParam param) {

        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));

        /** 数据隔离 本下 没有组织orgId的删除下面代码-------------开始 */
        UserContext userContextCache = sessionManager.getUserContext();
        //当前应用有权限的根orgId，以逗号分割，可据此查询其本下数据，需判空
        String authOrgIds = userContextCache.getAuthOrgIds();
        List<OrgVO> orgVOList = null;
        if (StringUtils.isNotBlank(authOrgIds)) {//移动端查询
            orgVOList = (List<OrgVO>) getRespData(iOrgApi.findChildrenByParentIds(Arrays.stream(authOrgIds.split(",")).map(Long::parseLong).collect(Collectors.toList())), true, "查询失败，获取当前本下组织信息失败。");
        } else {//pc端查询
            orgVOList = (List<OrgVO>) getRespData(iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()), true, "查询失败，获取当前本下组织信息失败。");
        }
        //普通组织 id
        List<Long> commonOrgIds = new ArrayList<>();
        //项目部 id
        List<Long> departmentIds = new ArrayList<>();
        orgVOList.stream().forEach(org -> {
            if (5 == org.getOrgType()) {
                //项目部
                departmentIds.add(org.getId());
            } else {
                //普通组织
                commonOrgIds.add(org.getId());
            }
        });
        if (CollectionUtils.isNotEmpty(commonOrgIds)) {
            /** 要求主表有orgId字段，保存单据所属组织 */
            param.getParams().put("orgId", new Parameter(QueryParam.IN, commonOrgIds));
        } else if (CollectionUtils.isNotEmpty(departmentIds)) {
            /** 要求主表有projectDepartmentId字段，保存单据所属项目部 */
            param.getParams().put("orgId", new Parameter(QueryParam.IN, departmentIds));
        }
        /** 数据隔离 本下 没有组织orgId的删除上面代码-------------结束！！！ */

        IPage<PurchaseStrategyChangeEntity> page = service.queryPage(param, false);
        IPage<PurchaseStrategyChangeVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), PurchaseStrategyChangeVO.class));

        return CommonResponse.success("查询列表数据成功！", pageData);
    }

    /**
     * 获取RPC数据
     * resp 返回值
     * isMustSuc 是否必须成功
     * errMsg 失败提示
     */
    private Object getRespData(CommonResponse<?> resp, boolean isMustSuc, String errMsg) {
        if (isMustSuc && !resp.isSuccess()) {
            throw new BusinessException(StringUtils.isNoneBlank(errMsg) ? errMsg : "调用Rpc服务失败");
        }
        return resp.getData();
    }


    /**
     * @Description 导出
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/excelExport", method = RequestMethod.POST)
    @ResponseBody
    public void excelExport(@RequestBody QueryParam param, HttpServletResponse response) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        param.getParams().put("tenant_id", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        param.setPageIndex(1);
        param.setPageSize(-1);
        /** 数据隔离 本下 没有组织orgId的删除下面代码 */
        param.getParams().put("orgId", new Parameter(QueryParam.IN, iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        List<PurchaseStrategyChangeEntity> list = service.queryList(param);
        //todo:字段翻译等等
        Map<String, Object> beans = new HashMap<>();
        beans.put("records", list);
        ExcelExport.getInstance().export("PurchaseStrategyChange-export.xlsx", beans, response);
    }

    /**
     * @Description 参照
     * @Return void
     */
    @RequestMapping(value = "/refPurchaseStrategyChangeData", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<IPage<PurchaseStrategyChangeVO>> refPurchaseStrategyChangeData(@RequestParam Integer pageNumber, @RequestParam Integer pageSize,
                                                                                         String condition,
                                                                                         String searchObject,
                                                                                         String searchText) {
        QueryParam param = new QueryParam();
        param.setPageSize(pageSize);
        param.setPageIndex(pageNumber);
        param.setSearchText(searchText);
        param.setSearchObject(searchObject);
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        if (StringUtils.isNotEmpty(condition)) {
            /** 处理condition */
            JSONObject _con = JSONObject.parseObject(condition);
        }

        IPage<PurchaseStrategyChangeEntity> page = service.queryPage(param, false);
        IPage<PurchaseStrategyChangeVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), PurchaseStrategyChangeVO.class));

        return CommonResponse.success("查询参照数据成功！", pageData);
    }
}
